#!/usr/bin/env python
import json
from pathlib import Path

# Go over module definitions from https://github.com/GetPageSpeed/nginx-extras/ in order to generate lookup dict from sonames
import os
import yaml

module_defs_dir = os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__)))) + '/nginx-extras/modules'

if not os.path.exists(module_defs_dir):
    print(f'{module_defs_dir} does not exist!')
    exit(1)

modules_by_soname = {}
modules_by_handle = {}

simple_module_files = [f for f in os.listdir(module_defs_dir) if f.endswith('.yml')]
for f in simple_module_files:
    handle = Path(f).stem
    with open(f'{module_defs_dir}/{f}', mode='r') as fp:
        # The FullLoader parameter handles the conversion from YAML
        # scalar values to Python the dictionary format
        module_info = yaml.load(fp, Loader=yaml.SafeLoader)
        modules_by_soname[module_info['soname']] = handle
        modules_by_handle[handle] = module_info

other_module_files = [f for f in os.listdir(module_defs_dir + '/others') if f.endswith('.yml')]
for f in other_module_files:
    handle = Path(f).stem
    with open(f'{module_defs_dir}/others/{f}', mode='r') as fp:
        # The FullLoader parameter handles the conversion from YAML
        # scalar values to Python the dictionary format
        module_info = yaml.load(fp, Loader=yaml.SafeLoader)
        sonames = module_info['soname']
        if isinstance(sonames, list):
            for soname in sonames:
                modules_by_soname[soname] = handle
        else:
            modules_by_soname[sonames] = handle
        modules_by_handle[handle] = module_info

modules = {
    'by_handle': modules_by_handle,
    'by_soname': modules_by_soname
}

with open('../ngm/modules.json', 'w') as f:
    json.dump(modules, f, ensure_ascii=False, indent=4)